#ifndef pppdialin_h
#define pppdialin_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

//#include <modapi_def.h>
//#include <modapi.h>
#ifndef DIALOG_H
	#include <dialog.h>
#endif
class MODULE_pppdialin: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_pppdialin */
public:
	MODULE_pppdialin (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	void setmenu (DIALOG&dia,
		 MENU_CONTEXT context);
    /*~PROTOEND~ MODULE_pppdialin */
};

#include "pppdialin.p"

#endif
